$title	DICE version 1994 -- with cosmetic revisions

$include dicedata

VARIABLES
	C(t)		Consumption trillion US dollars
	K(t)		Capital stock trillion US dollars
	I(t)		Investment trillion US dollars
	D(t)		Damage
	A(t)		Abatement cost
	Y(t)		Output net abatement and damage costs 
	Q(t)		Gross Output 
	E(t)		CO2-equiv emissions billion t
	M(t)		CO2-equiv concentration billion t
	MIU(t)		Emission control rate GHGs
	FORC(t)		Radiative forcing - W per m2
	TE(t)		Temperature - atmosphere C
	TL(t)		Temperature - lower ocean C
	UTILITY		Maximand;

POSITIVE VARIABLES MIU, E, TE, M, Y, C, K, I;

EQUATIONS
	UTIL		Objective function
	YY(t)		Output
	AA(t)		Abatement
	DD(t)		Damage
	QQ(t)		Underlying production function
	CC(t)		Consumption
	KK(t)		Capital balance
	KC(t)		Terminal condition of K
	EE(t)		Emissions process
	FORCE(t)	Radiative forcing equation
	MM(t)		CO2 distribution equation
	TTE(t)		Temperature-climate equation for atmosphere
	TLE(t)		Temperature-climate equation for lower oceans;

CC(t)..		C(t) =E= Y(t) - I(t);
YY(t)..		Y(t) =E= Q(t) - A(t)*Q(t) - D(t)*Y(t);
AA(t)..		A(t) =E= b1 * MIU(t)**b2;
DD(t)..		D(t) =E= (a1/9)*SQR(TE(t));
QQ(t)..		Q(t) =E= al(t) * L(t)**(1-gamma) * K(t)**gamma;
KK(t)..		K(t) =L= (1-dk)**10 * K(t-1) + 10 * I(t-1) + (k0*0.9)$tfirst(t);
KC(tlast)..	dk * K(tlast) =L= I(tlast);
EE(t)..		E(t) =G= 10 * sigma(t) * (1-MIU(t)) * Q(t);
FORCE(t)..	FORC(t) =E= 4.1*(LOG(M(t)/590)/LOG(2)) + forcoth(t);
MM(t)..		M(t) =E= 590 + atret*E(t) + (1-deltam)*(M(t-1)-590) + m0$tfirst(t);
TTE(t)..	TE(t) =E= TE(t-1)+c1*(FORC(t-1)-lam*TE(t-1)-c3*(TE(t-1)-TL(t-1))) + t0$tfirst(t);
TLE(t)..	TL(t) =E= TL(t-1)+c4*(TE(t-1)-TL(t-1)) + tl0$tfirst(t);
UTIL..		UTILITY =E= SUM(t, 10 *rr(t)*L(t)*LOG(C(t)/L(t))/0.55)
		   + SUM(tlast, rr(tlast)*(phik*K(tlast)+phim*M(tlast)+phite*TE(tlast)));

*	Assign a naive starting point which is in the domain of the functions:

C.L(t) = 1; K.L(t) = 1; I.L(t) = 1; Y.L(t) = 1; Q.L(t) = 1; E.L(t) =1;
M.L(t) = 1; MIU.L(t) = 1; FORC.L(t) = 1; TE.L(t) = 1; TL.L(t) = 1;
UTILITY.L = 1;

* Upper and Lower Bounds for economic reasons or stability

MIU.UP(t) = 0.99; MIU.LO(t) = 0.01; K.LO(t) = 1; TE.UP(t) = 20;
M.LO(t) = 600; C.LO(t) = 2;

MODEL CO2 /all/;
SOLVE CO2 maximizing UTILITY using NLP;

