$title	DICE version 1994 -- with cosmetic revisions

$include dicedata

alias (t,tp); alias(tp,tpp);

PARAMETER
	teref(t)	Reference values of temperature,
	grad(tp,t)	Local dependence of TE(tp) on E(t),
	eref(t)		Reference values of emissions,
	gradt(tp)	Local dependence of transversality terms on emissions;

VARIABLES
	C(t)		Consumption trillion US dollars
	K(t)		Capital stock trillion US dollars
	I(t)		Investment trillion US dollars
	Y(t)		Output net abatement and damage costs 
	D(t)		Damage
	A(t)		Abatement cost
	Q(t)		Gross Output 
	E(t)		CO2-equiv emissions billion t
	MIU(t)		Emission control rate GHGs

	PY(t)		Output
	PQ(t)		Underlying production function
	PC(t)		Consumption
	PA(t)		Shadow price on abatement cost coefficent
	PD(t)		shadow price on damage coefficent
	PK(t)		Capital balance
	PKC(t)		Terminal condition of K
	PE(t)		Emissions process
	PD(t)		Shadow price for climate,
	KT		Terminal Capital stock,
	PKT		Shadow price on terminal capital;

POSITIVE VARIABLES MIU, Y, C, K, I, PE;

EQUATIONS
	YY(t)		Output,
	AA(t)		Abatement,
	DD(t)		Damage (linear climate model),
	QQ(t)		Underlying production function,
	CC(t)		Consumption,
	KK(t)		Capital balance,
	KC(t)		Terminal condition of K,
	EE(t)		Emissions process,

	EQ_C(t)		Consumption trillion US dollars,
	EQ_K(t)		Capital stock trillion US dollars,
	EQ_I(t)		Investment trillion US dollars,
	EQ_Y(t)		Output net abatement and damage costs,
	EQ_Q(t)		Gross Output,
	EQ_A(t)		Abatement,
	EQ_D(t)		Damage,
	EQ_MIU(t)	Emission control rate GHGs
	EQ_E(t)		CO2-equiv emissions billion t
	EQ_PKT		Equilibrium for terminal capital market,
	EQ_KT		Equilibrium for terminal capital stock;


CC(t)..	        C(t) =E= Y(t) - I(t);
YY(t)..	        Y(t) =E= Q(t)*(1-A(t)) - D(t)*Y(t);
AA(t)..	        A(t) =E=  b1 * MIU(t)**b2;
QQ(t)..	        Q(t) =E= al(t) * L(t)**(1-gamma) * K(t)**gamma;
KK(t)..	        K(t) =L= (1-dk)**10 * K(t-1) + 10 * I(t-1) + (k0*0.9)$tfirst(t);
KC(tlast)..	dk * K(tlast) =L= I(tlast);
EE(t)..	        E(t) =G= 10 * sigma(t) * (1-MIU(t)) * Q(t);
DD(t)..	        D(t) =E= (a1/9)*SQR(teref(t) + sum(tp, grad(t,tp)*(E(tp)-eref(tp))));
EQ_C(t)..       10 * rr(t) * L(t) / (0.55*C(t)) =E= PC(t);
EQ_K(t)..       K(t) * (PK(t) + (PKC(t)*dk-rr(t)*phik)$tlast(t)) =G=
	        gamma * PQ(t) * Q(t) + (PK(t+1)+PKT$tlast(t)) * (1-dk)**10 * K(t);
EQ_I(t)..       PC(t) =E= 10 * (PK(t+1) + PKT$tlast(t)) + PKC(t)$tlast(t);
EQ_Y(t)..       PY(t) * (1+D(t)) =E= PC(t);
EQ_Q(t)..       PQ(t) =E= PY(t)*(1-A(t)) - PE(t)*10*sigma(t)*(1-MIU(t));
EQ_E(t)..       -PE(t) =E= SUM(tp, PD(tp)*grad(tp,t)*2*(a1/9)*(teref(tp) + sum(tpp, grad(t,tpp)*(E(tpp)-eref(tpp))))) + SUM(tlast, rr(tlast)*gradt(t));
EQ_A(t)..       PA(t) + PY(t)*Q(t) =E= 0;
EQ_D(t)..       PD(t) + PY(t)*Y(t) =E= 0;
EQ_MIU(t)..	-PE(t)*10*sigma(t)*Q(t) =E= PA(t) * b1 * b2 * MIU(t)**(b2-1);
EQ_PKT..	SUM(tlast, 10 * I(tlast) + K(tlast) * (1-dk/100)**10) =E= KT;
EQ_KT..		SUM(tlast(t), I(t)/I(t-1) - Y(t)/Y(t-1)) =E= 0;


MODEL DICEMCP /CC.PC, YY.PY, AA.PA, QQ.PQ, KK.PK, KC.PKC, EE.PE, DD.PD, EQ_C.C,
     EQ_K.K, EQ_I.I, EQ_Y.Y, EQ_Q.Q, EQ_E.E, EQ_A.A, EQ_D.D, EQ_MIU.MIU, 
     EQ_KT.KT, EQ_PKT.PKT /;

PARAMETERS
	m(t)		CO2-equiv concentration billion t,
	forc(t)		Radiative forcing - W per m2,
	te(t)		Temperature - atmosphere C,
	tl(t)		Temperature - lower ocean C,
	termv		Terminal value of atmophere,
	deltaE		Difference iterval /0.001/;

m(tfirst) = M0;
te(tfirst) = T0;
tl(tfirst) = TL0;

parameter	teinit(t)	Tracking of initial temperature trajectory;

m(t) = m0;
te(t) = t0;
tl(t) = tl0;
$onecho >climatemodel.gms
loop(t,
	m(t)		= 590 + atret*eref(t) + (1-deltam)*(m(t-1)-590) + m0$tfirst(t);
	forc(t)		= 4.1*(LOG(m(t)/590)/LOG(2)) + forcoth(t);
	te(t)		= te(t-1)+c1*(forc(t-1)-lam*te(t-1)-c3*(te(t-1)-tl(t-1))) + t0$tfirst(t);
	tl(t)		= tl(t-1)+c4*(te(t-1)-tl(t-1)) + tl0$tfirst(t);
	teref(t)	= te(t);
);
$offecho

$onecho >jacobian.gms
	eref(t) = E.L(t);
$include climatemodel
	teinit(t)  = teref(t);
	termv  = sum(tlast, phim*m(tlast)+phite*te(tlast));
	grad(t,tp) = 0;	gradt(t) = 0;
	loop(tp, eref(tp) = eref(tp) + deltaE;
$include climatemodel
	  grad(t,tp) = (teref(t)-teinit(t)) / deltaE;
	  gradt(tp) = (sum(tlast, phim*m(tlast)+phite*te(tlast))-termv) / deltaE;
	  eref(tp) = eref(tp) - deltaE;);
	  teref(t) = teinit(t);
$offecho

*	Begin with a replication of the NLP solution:

execute_load 'nlpdecompsol.gdx',eref,C,K,I,D,A,Y,Q,E,MIU,YY,AA,QQ,CC,KK,KC,EE,DD;
PC.L(t) = CC.M(t); PY.L(t) = YY.M(t); PA.L(t) = AA.M(t); PD.L(t) =
DD.M(t); PQ.L(t) = QQ.M(t); PK.L(t) = KK.M(t); PKC.L(t) = KC.M(t);
PE.L(t) = -EE.M(t);

*	No adjustments yet:

KT.FX = 0; PKT.FX = 0;

$INCLUDE jacobian
DICEMCP.ITERLIM = 0;
SOLVE DICEMCP USING MCP;
